==> pydftutils-0.2.0.tar.gz: pydftutils-0.2.0/pyDFTutils/siesta/siesta_basis.py <==

withf_basis = {
    #"La": "5\nn=5  0  1\n3.889 \n1.0 \nn=6  0  2\n9.113 6.906 \n1.0 1.0 \nn=5  1  1\n4.548 \n1.0 \nn=6  1  1\n9.113 \n1.0 \nn=5  2  2\n7.55 5.398 \n1.0 1.0 \n",
    "Ce": "6\nn=5  0  1\n3.805 \n1.0 \nn=6  0  2\n9.041 6.837 \n1.0 1.0 \nn=5  1  1\n4.458 \n1.0 \nn=6  1  1\n9.041 \n1.0 \nn=5  2  2\n7.489 5.339 \n1.0 1.0 \nn=4  3  2\n4.114 2.494 \n1.0 1.0 \n",
    "Pr": "6\nn=5  0  1\n3.737 \n1.0 \nn=6  0  2\n8.879 6.702 \n1.0 1.0 \nn=5  1  1\n4.387 \n1.0 \nn=6  1  1\n8.879 \n1.0 \nn=5  2  2\n7.46 5.307 \n1.0 1.0 \nn=4  3  2\n3.944 2.369 \n1.0 1.0 \n",
    "Nd": "6\nn=5  0  1\n3.67 \n1.0 \nn=6  0  2\n8.808 6.641 \n1.0 1.0 \nn=5  1  1\n4.317 \n1.0 \nn=6  1  1\n8.808 \n1.0 \nn=5  2  2\n7.445 5.285 \n1.0 1.0 \nn=4  3  2\n3.805 2.271 \n1.0 1.0 \n",
    "Pm": "6\nn=5  0  1\n3.611 \n1.0 \nn=6  0  2\n8.756 6.588 \n1.0 1.0 \nn=5  1  1\n4.257 \n1.0 \nn=6  1  1\n8.756 \n1.0 \nn=5  2  2\n7.43 5.269 \n1.0 1.0 \nn=4  3  2\n3.692 2.189 \n1.0 1.0 \n",
    "Sm": "6\nn=5  0  1\n3.554 \n1.0 \nn=6  0  2\n8.668 6.516 \n1.0 1.0 \nn=5  1  1\n4.197 \n1.0 \nn=6  1  1\n8.668 \n1.0 \nn=5  2  2\n7.445 5.269 \n1.0 1.0 \nn=4  3  2\n3.59 2.115 \n1.0 1.0 \n",
    "Eu": "6\nn=5  0  1\n3.497 \n1.0 \nn=6  0  2\n8.599 6.458 \n1.0 1.0 \nn=5  1  1\n4.139 \n1.0 \nn=6  1  1\n8.599 \n1.0 \nn=5  2  2\n7.46 5.275 \n1.0 1.0 \nn=4  3  2\n3.504 2.052 \n1.0 1.0 \n",
    "Gd": "6\nn=5  0  1\n3.442 \n1.0 \nn=6  0  2\n8.514 6.374 \n1.0 1.0 \nn=5  1  1\n4.089 \n1.0 \nn=6  1  1\n8.514 \n1.0 \nn=5  2  2\n7.489 5.285 \n1.0 1.0 \nn=4  3  2\n3.435 1.997 \n1.0 1.0 \n",
    "Tb": "6\nn=5  0  1\n3.394 \n1.0 \nn=6  0  2\n8.395 6.279 \n1.0 1.0 \nn=5  1  1\n4.04 \n1.0 \nn=6  1  1\n8.395 \n1.0 \nn=5  2  2\n7.52 5.301 \n1.0 1.0 \nn=4  3  2\n3.366 1.948 \n1.0 1.0 \n",
    "Dy": "6\nn=5  0  1\n3.346 \n1.0 \nn=6  0  2\n8.295 6.186 \n1.0 1.0 \nn=5  1  1\n3.992 \n1.0 \nn=6  1  1\n8.295 \n1.0 \nn=5  2  2\n7.565 5.323 \n1.0 1.0 \nn=4  3  2\n3.306 1.901 \n1.0 1.0 \n",
    "Ho": "6\nn=5  0  1\n3.293 \n1.0 \nn=6  0  2\n8.179 6.093 \n1.0 1.0 \nn=5  1  1\n3.944 \n1.0 \nn=6  1  1\n8.179 \n1.0 \nn=5  2  2\n7.61 5.349 \n1.0 1.0 \nn=4  3  2\n3.254 1.86 \n1.0 1.0 \n",
    "Er": "6\nn=5  0  1\n3.247 \n1.0 \nn=6  0  2\n8.049 5.972 \n1.0 1.0 \nn=5  1  1\n3.897 \n1.0 \nn=6  1  1\n8.049 \n1.0 \nn=5  2  2\n7.656 5.387 \n1.0 1.0 \nn=4  3  2\n3.208 1.821 \n1.0 1.0 \n",
    "Tm": "6\nn=5  0  1\n3.202 \n1.0 \nn=6  0  2\n7.921 5.872 \n1.0 1.0 \nn=5  1  1\n3.858 \n1.0 \nn=6  1  1\n7.921 \n1.0 \nn=5  2  2\n7.718 5.419 \n1.0 1.0 \nn=4  3  2\n3.163 1.785 \n1.0 1.0 \n",
    "Yb": "6\nn=5  0  1\n3.163 \n1.0 \nn=6  0  2\n7.796 5.761 \n1.0 1.0 \nn=5  1  1\n3.812 \n1.0 \nn=6  1  1\n7.796 \n1.0 \nn=5  2  2\n7.78 5.468 \n1.0 1.0 \nn=4  3  2\n3.119 1.753 \n1.0 1.0 \n"
}

fincore_basis ={
    #"La": "4\nn=5  0  1\n3.889 \n1.0 \nn=6  0  2\n9.113 6.906 \n1.0 1.0 \nn=5  1  1\n4.548 \n1.0 \nn=6  1  1\n9.113 \n1.0 \nn=5  2  2\n7.55 5.398 \n1.0 1.0 \n",
    "Ce": "5\nn=5  0  1\n3.805 \n1.0 \nn=6  0  2\n8.968 6.776 \n1.0 1.0 \nn=5  1  1\n4.458 \n1.0 \nn=6  1  1\n8.968 \n1.0 \nn=5  2  2\n7.489 5.339 \n1.0 1.0 \n",
    "Pr": "5\nn=5  0  1\n3.737 \n1.0 \nn=6  0  2\n8.791 6.621 \n1.0 1.0 \nn=5  1  1\n4.387 \n1.0 \nn=6  1  1\n8.791 \n1.0 \nn=5  2  2\n7.46 5.307 \n1.0 1.0 \n",
    "Nd": "5\nn=5  0  1\n3.67 \n1.0 \nn=6  0  2\n8.634 6.49 \n1.0 1.0 \nn=5  1  1\n4.317 \n1.0 \nn=6  1  1\n8.634 \n1.0 \nn=5  2  2\n7.445 5.285 \n1.0 1.0 \n",
    "Pm": "5\nn=5  0  1\n3.611 \n1.0 \nn=6  0  2\n8.446 6.33 \n1.0 1.0 \nn=5  1  1\n4.257 \n1.0 \nn=6  1  1\n8.446 \n1.0 \nn=5  2  2\n7.43 5.269 \n1.0 1.0 \n",
    "Sm": "5\nn=5  0  1\n3.554 \n1.0 \nn=6  0  2\n8.328 6.223 \n1.0 1.0 \nn=5  1  1\n4.197 \n1.0 \nn=6  1  1\n8.328 \n1.0 \nn=5  2  2\n7.445 5.269 \n1.0 1.0 \n",
    "Eu": "5\nn=5  0  1\n3.497 \n1.0 \nn=6  0  2\n8.278 6.186 \n1.0 1.0 \nn=5  1  1\n4.139 \n1.0 \nn=6  1  1\n8.278 \n1.0 \nn=5  2  2\n7.46 5.275 \n1.0 1.0 \n",
    "Gd": "5\nn=5  0  1\n3.442 \n1.0 \nn=6  0  2\n8.278 6.179 \n1.0 1.0 \nn=5  1  1\n4.089 \n1.0 \nn=6  1  1\n8.278 \n1.0 \nn=5  2  2\n7.489 5.285 \n1.0 1.0 \n",
    "Tb": "5\nn=5  0  1\n3.394 \n1.0 \nn=6  0  2\n8.147 6.063 \n1.0 1.0 \nn=5  1  1\n4.04 \n1.0 \nn=6  1  1\n8.147 \n1.0 \nn=5  2  2\n7.52 5.301 \n1.0 1.0 \n",
    "Dy": "5\nn=5  0  1\n3.346 \n1.0 \nn=6  0  2\n7.969 5.919 \n1.0 1.0 \nn=5  1  1\n3.992 \n1.0 \nn=6  1  1\n7.969 \n1.0 \nn=5  2  2\n7.565 5.323 \n1.0 1.0 \n",
    "Ho": "5\nn=5  0  1\n3.293 \n1.0 \nn=6  0  2\n7.827 5.79 \n1.0 1.0 \nn=5  1  1\n3.944 \n1.0 \nn=6  1  1\n7.827 \n1.0 \nn=5  2  2\n7.61 5.349 \n1.0 1.0 \n",
    "Er": "5\nn=5  0  1\n3.247 \n1.0 \nn=6  0  2\n7.626 5.624 \n1.0 1.0 \nn=5  1  1\n3.897 \n1.0 \nn=6  1  1\n7.626 \n1.0 \nn=5  2  2\n7.656 5.387 \n1.0 1.0 \n",
    "Tm": "5\nn=5  0  1\n3.202 \n1.0 \nn=6  0  2\n7.474 5.49 \n1.0 1.0 \nn=5  1  1\n3.858 \n1.0 \nn=6  1  1\n7.474 \n1.0 \nn=5  2  2\n7.718 5.419 \n1.0 1.0 \n",
    "Yb": "5\nn=5  0  1\n3.163 \n1.0 \nn=6  0  2\n7.312 5.36 \n1.0 1.0 \nn=5  1  1\n3.812 \n1.0 \nn=6  1  1\n7.312 \n1.0 \nn=5  2  2\n7.78 5.468 \n1.0 1.0 \n"
}

def get_basis(element, fincore=False):
    if not fincore:
        return withf_basis[element]
    elif basis == "fincore":
        return fincore_basis[element]
    else:
        raise ValueError("Invalid basis set: {}".format(basis))

if __name__ == "__main__":
    print(get_basis("La"))
    print(get_basis("La", fincore=True))
    print(get_basis("Ce"))
    print(get_basis("Ce", fincore=True))

==> pydftutils-0.2.8.tar.gz: pydftutils-0.2.8/pyDFTutils/siesta/siesta_basis.py <==

withf_basis = {
    #"La": "5\nn=5  0  1\n3.889 \n1.0 \nn=6  0  2\n9.113 6.906 \n1.0 1.0 \nn=5  1  1\n4.548 \n1.0 \nn=6  1  1\n9.113 \n1.0 \nn=5  2  2\n7.55 5.398 \n1.0 1.0 \n",
    "Ce": "6\nn=5  0  1\n3.805 \n1.0 \nn=6  0  2\n9.041 6.837 \n1.0 1.0 \nn=5  1  1\n4.458 \n1.0 \nn=6  1  1\n9.041 \n1.0 \nn=5  2  2\n7.489 5.339 \n1.0 1.0 \nn=4  3  2\n4.114 2.494 \n1.0 1.0 \n",
    "Pr": "6\nn=5  0  1\n3.737 \n1.0 \nn=6  0  2\n8.879 6.702 \n1.0 1.0 \nn=5  1  1\n4.387 \n1.0 \nn=6  1  1\n8.879 \n1.0 \nn=5  2  2\n7.46 5.307 \n1.0 1.0 \nn=4  3  2\n3.944 2.369 \n1.0 1.0 \n",
    "Nd": "6\nn=5  0  1\n3.67 \n1.0 \nn=6  0  2\n8.808 6.641 \n1.0 1.0 \nn=5  1  1\n4.317 \n1.0 \nn=6  1  1\n8.808 \n1.0 \nn=5  2  2\n7.445 5.285 \n1.0 1.0 \nn=4  3  2\n3.805 2.271 \n1.0 1.0 \n",
    "Pm": "6\nn=5  0  1\n3.611 \n1.0 \nn=6  0  2\n8.756 6.588 \n1.0 1.0 \nn=5  1  1\n4.257 \n1.0 \nn=6  1  1\n8.756 \n1.0 \nn=5  2  2\n7.43 5.269 \n1.0 1.0 \nn=4  3  2\n3.692 2.189 \n1.0 1.0 \n",
    "Sm": "6\nn=5  0  1\n3.554 \n1.0 \nn=6  0  2\n8.668 6.516 \n1.0 1.0 \nn=5  1  1\n4.197 \n1.0 \nn=6  1  1\n8.668 \n1.0 \nn=5  2  2\n7.445 5.269 \n1.0 1.0 \nn=4  3  2\n3.59 2.115 \n1.0 1.0 \n",
    "Eu": "6\nn=5  0  1\n3.497 \n1.0 \nn=6  0  2\n8.599 6.458 \n1.0 1.0 \nn=5  1  1\n4.139 \n1.0 \nn=6  1  1\n8.599 \n1.0 \nn=5  2  2\n7.46 5.275 \n1.0 1.0 \nn=4  3  2\n3.504 2.052 \n1.0 1.0 \n",
    "Gd": "6\nn=5  0  1\n3.442 \n1.0 \nn=6  0  2\n8.514 6.374 \n1.0 1.0 \nn=5  1  1\n4.089 \n1.0 \nn=6  1  1\n8.514 \n1.0 \nn=5  2  2\n7.489 5.285 \n1.0 1.0 \nn=4  3  2\n3.435 1.997 \n1.0 1.0 \n",
    "Tb": "6\nn=5  0  1\n3.394 \n1.0 \nn=6  0  2\n8.395 6.279 \n1.0 1.0 \nn=5  1  1\n4.04 \n1.0 \nn=6  1  1\n8.395 \n1.0 \nn=5  2  2\n7.52 5.301 \n1.0 1.0 \nn=4  3  2\n3.366 1.948 \n1.0 1.0 \n",
    "Dy": "6\nn=5  0  1\n3.346 \n1.0 \nn=6  0  2\n8.295 6.186 \n1.0 1.0 \nn=5  1  1\n3.992 \n1.0 \nn=6  1  1\n8.295 \n1.0 \nn=5  2  2\n7.565 5.323 \n1.0 1.0 \nn=4  3  2\n3.306 1.901 \n1.0 1.0 \n",
    "Ho": "6\nn=5  0  1\n3.293 \n1.0 \nn=6  0  2\n8.179 6.093 \n1.0 1.0 \nn=5  1  1\n3.944 \n1.0 \nn=6  1  1\n8.179 \n1.0 \nn=5  2  2\n7.61 5.349 \n1.0 1.0 \nn=4  3  2\n3.254 1.86 \n1.0 1.0 \n",
    "Er": "6\nn=5  0  1\n3.247 \n1.0 \nn=6  0  2\n8.049 5.972 \n1.0 1.0 \nn=5  1  1\n3.897 \n1.0 \nn=6  1  1\n8.049 \n1.0 \nn=5  2  2\n7.656 5.387 \n1.0 1.0 \nn=4  3  2\n3.208 1.821 \n1.0 1.0 \n",
    "Tm": "6\nn=5  0  1\n3.202 \n1.0 \nn=6  0  2\n7.921 5.872 \n1.0 1.0 \nn=5  1  1\n3.858 \n1.0 \nn=6  1  1\n7.921 \n1.0 \nn=5  2  2\n7.718 5.419 \n1.0 1.0 \nn=4  3  2\n3.163 1.785 \n1.0 1.0 \n",
    "Yb": "6\nn=5  0  1\n3.163 \n1.0 \nn=6  0  2\n7.796 5.761 \n1.0 1.0 \nn=5  1  1\n3.812 \n1.0 \nn=6  1  1\n7.796 \n1.0 \nn=5  2  2\n7.78 5.468 \n1.0 1.0 \nn=4  3  2\n3.119 1.753 \n1.0 1.0 \n"
}

fincore_basis ={
    #"La": "4\nn=5  0  1\n3.889 \n1.0 \nn=6  0  2\n9.113 6.906 \n1.0 1.0 \nn=5  1  1\n4.548 \n1.0 \nn=6  1  1\n9.113 \n1.0 \nn=5  2  2\n7.55 5.398 \n1.0 1.0 \n",
    "Ce": "5\nn=5  0  1\n3.805 \n1.0 \nn=6  0  2\n8.968 6.776 \n1.0 1.0 \nn=5  1  1\n4.458 \n1.0 \nn=6  1  1\n8.968 \n1.0 \nn=5  2  2\n7.489 5.339 \n1.0 1.0 \n",
    "Pr": "5\nn=5  0  1\n3.737 \n1.0 \nn=6  0  2\n8.791 6.621 \n1.0 1.0 \nn=5  1  1\n4.387 \n1.0 \nn=6  1  1\n8.791 \n1.0 \nn=5  2  2\n7.46 5.307 \n1.0 1.0 \n",
    "Nd": "5\nn=5  0  1\n3.67 \n1.0 \nn=6  0  2\n8.634 6.49 \n1.0 1.0 \nn=5  1  1\n4.317 \n1.0 \nn=6  1  1\n8.634 \n1.0 \nn=5  2  2\n7.445 5.285 \n1.0 1.0 \n",
    "Pm": "5\nn=5  0  1\n3.611 \n1.0 \nn=6  0  2\n8.446 6.33 \n1.0 1.0 \nn=5  1  1\n4.257 \n1.0 \nn=6  1  1\n8.446 \n1.0 \nn=5  2  2\n7.43 5.269 \n1.0 1.0 \n",
    "Sm": "5\nn=5  0  1\n3.554 \n1.0 \nn=6  0  2\n8.328 6.223 \n1.0 1.0 \nn=5  1  1\n4.197 \n1.0 \nn=6  1  1\n8.328 \n1.0 \nn=5  2  2\n7.445 5.269 \n1.0 1.0 \n",
    "Eu": "5\nn=5  0  1\n3.497 \n1.0 \nn=6  0  2\n8.278 6.186 \n1.0 1.0 \nn=5  1  1\n4.139 \n1.0 \nn=6  1  1\n8.278 \n1.0 \nn=5  2  2\n7.46 5.275 \n1.0 1.0 \n",
    "Gd": "5\nn=5  0  1\n3.442 \n1.0 \nn=6  0  2\n8.278 6.179 \n1.0 1.0 \nn=5  1  1\n4.089 \n1.0 \nn=6  1  1\n8.278 \n1.0 \nn=5  2  2\n7.489 5.285 \n1.0 1.0 \n",
    "Tb": "5\nn=5  0  1\n3.394 \n1.0 \nn=6  0  2\n8.147 6.063 \n1.0 1.0 \nn=5  1  1\n4.04 \n1.0 \nn=6  1  1\n8.147 \n1.0 \nn=5  2  2\n7.52 5.301 \n1.0 1.0 \n",
    "Dy": "5\nn=5  0  1\n3.346 \n1.0 \nn=6  0  2\n7.969 5.919 \n1.0 1.0 \nn=5  1  1\n3.992 \n1.0 \nn=6  1  1\n7.969 \n1.0 \nn=5  2  2\n7.565 5.323 \n1.0 1.0 \n",
    "Ho": "5\nn=5  0  1\n3.293 \n1.0 \nn=6  0  2\n7.827 5.79 \n1.0 1.0 \nn=5  1  1\n3.944 \n1.0 \nn=6  1  1\n7.827 \n1.0 \nn=5  2  2\n7.61 5.349 \n1.0 1.0 \n",
    "Er": "5\nn=5  0  1\n3.247 \n1.0 \nn=6  0  2\n7.626 5.624 \n1.0 1.0 \nn=5  1  1\n3.897 \n1.0 \nn=6  1  1\n7.626 \n1.0 \nn=5  2  2\n7.656 5.387 \n1.0 1.0 \n",
    "Tm": "5\nn=5  0  1\n3.202 \n1.0 \nn=6  0  2\n7.474 5.49 \n1.0 1.0 \nn=5  1  1\n3.858 \n1.0 \nn=6  1  1\n7.474 \n1.0 \nn=5  2  2\n7.718 5.419 \n1.0 1.0 \n",
    "Yb": "5\nn=5  0  1\n3.163 \n1.0 \nn=6  0  2\n7.312 5.36 \n1.0 1.0 \nn=5  1  1\n3.812 \n1.0 \nn=6  1  1\n7.312 \n1.0 \nn=5  2  2\n7.78 5.468 \n1.0 1.0 \n"
}


withf_basis_f_sz = {
    #"La": "5\nn=5  0  1\n3.889 \n1.0 \nn=6  0  2\n9.113 6.906 \n1.0 1.0 \nn=5  1  1\n4.548 \n1.0 \nn=6  1  1\n9.113 \n1.0 \nn=5  2  2\n7.55 5.398 \n1.0 1.0 \n",
    "Ce": "6\nn=5  0  1\n3.805 \n1.0 \nn=6  0  2\n9.041 6.837 \n1.0 1.0 \nn=5  1  1\n4.458 \n1.0 \nn=6  1  1\n9.041 \n1.0 \nn=5  2  2\n7.489 5.339 \n1.0 1.0 \nn=4  3 1\n4.1 \n1.0  \n",
    "Pr": "6\nn=5  0  1\n3.737 \n1.0 \nn=6  0  2\n8.879 6.702 \n1.0 1.0 \nn=5  1  1\n4.387 \n1.0 \nn=6  1  1\n8.879 \n1.0 \nn=5  2  2\n7.46 5.307 \n1.0 1.0 \nn=4  3  1\n3.9 \n1.0  \n",
    "Nd": "6\nn=5  0  1\n3.67 \n1.0 \nn=6  0  2\n8.808 6.641 \n1.0 1.0 \nn=5  1  1\n4.317 \n1.0 \nn=6  1  1\n8.808 \n1.0 \nn=5  2  2\n7.445 5.285 \n1.0 1.0 \nn=4  3  1\n3.8 \n1.0  \n",
    "Pm": "6\nn=5  0  1\n3.611 \n1.0 \nn=6  0  2\n8.756 6.588 \n1.0 1.0 \nn=5  1  1\n4.257 \n1.0 \nn=6  1  1\n8.756 \n1.0 \nn=5  2  2\n7.43 5.269 \n1.0 1.0 \nn=4  3  1\n3.6 \n1.0  \n",
    "Sm": "6\nn=5  0  1\n3.554 \n1.0 \nn=6  0  2\n8.668 6.516 \n1.0 1.0 \nn=5  1  1\n4.197 \n1.0 \nn=6  1  1\n8.668 \n1.0 \nn=5  2  2\n7.445 5.269 \n1.0 1.0 \nn=4  3 1\n3.5 \n1.0  \n",
    "Eu": "6\nn=5  0  1\n3.497 \n1.0 \nn=6  0  2\n8.599 6.458 \n1.0 1.0 \nn=5  1  1\n4.139 \n1.0 \nn=6  1  1\n8.599 \n1.0 \nn=5  2  2\n7.46 5.275 \n1.0 1.0 \nn=4  3  1\n3.5 \n1.0  \n",
    "Gd": "6\nn=5  0  1\n3.442 \n1.0 \nn=6  0  2\n8.514 6.374 \n1.0 1.0 \nn=5  1  1\n4.089 \n1.0 \nn=6  1  1\n8.514 \n1.0 \nn=5  2  2\n7.489 5.285 \n1.0 1.0 \nn=4  3 1\n3.4 \n1.0  \n",
    "Tb": "6\nn=5  0  1\n3.394 \n1.0 \nn=6  0  2\n8.395 6.279 \n1.0 1.0 \nn=5  1  1\n4.04 \n1.0 \nn=6  1  1\n8.395 \n1.0 \nn=5  2  2\n7.52 5.301 \n1.0 1.0 \nn=4  3   1\n3.3 \n1.0  \n",
    "Dy": "6\nn=5  0  1\n3.346 \n1.0 \nn=6  0  2\n8.295 6.186 \n1.0 1.0 \nn=5  1  1\n3.992 \n1.0 \nn=6  1  1\n8.295 \n1.0 \nn=5  2  2\n7.565 5.323 \n1.0 1.0 \nn=4  3 1\n3.3 \n1.0  \n",
    "Ho": "6\nn=5  0  1\n3.293 \n1.0 \nn=6  0  2\n8.179 6.093 \n1.0 1.0 \nn=5  1  1\n3.944 \n1.0 \nn=6  1  1\n8.179 \n1.0 \nn=5  2  2\n7.61 5.349 \n1.0 1.0 \nn=4  3  1\n3.2 \n1.0  \n",
    "Er": "6\nn=5  0  1\n3.247 \n1.0 \nn=6  0  2\n8.049 5.972 \n1.0 1.0 \nn=5  1  1\n3.897 \n1.0 \nn=6  1  1\n8.049 \n1.0 \nn=5  2  2\n7.656 5.387 \n1.0 1.0 \nn=4  3 1\n3.2 \n1.0  \n",
    "Tm": "6\nn=5  0  1\n3.202 \n1.0 \nn=6  0  2\n7.921 5.872 \n1.0 1.0 \nn=5  1  1\n3.858 \n1.0 \nn=6  1  1\n7.921 \n1.0 \nn=5  2  2\n7.718 5.419 \n1.0 1.0 \nn=4  3 1\n3.1 \n1.0  \n",
    "Yb": "6\nn=5  0  1\n3.163 \n1.0 \nn=6  0  2\n7.796 5.761 \n1.0 1.0 \nn=5  1  1\n3.812 \n1.0 \nn=6  1  1\n7.796 \n1.0 \nn=5  2  2\n7.78 5.468 \n1.0 1.0 \nn=4  3  1\n3.1 \n1.0  \n"
}


def get_basis(element, fincore=False, f_sz=True):
    if not fincore:
        if f_sz:
            return withf_basis_f_sz[element]
        else:
            return withf_basis[element]
    elif basis == "fincore":
        return fincore_basis[element]
    else:
        raise ValueError("Invalid basis set: {}".format(basis))

if __name__ == "__main__":
    #print(get_basis("La"))
    #print(get_basis("La", fincore=True))
    print(get_basis("Ce"))
    print(get_basis("Ce", fincore=True))
